@@ -73,6 +73,12 @@ def setup(settings_path=None, **settings_patches):
         # Setup git
         local('su -c "git config --global user.name \'beanstalk\'" - beanstalk')
         local('su -c "git config --global user.email beanstalk@beanstalk-stack.com" - beanstalk')
+        # Setup .ssh
+        local('mkdir -p ~beanstalk/.ssh')
+        local('chmod 700 ~beanstalk/.ssh')
+        local('touch ~beanstalk/.ssh/authorized_keys')
+        local('chmod 644 ~beanstalk/.ssh/authorized_keys')
+        local('chown -R beanstalk:beanstalk ~beanstalk/.ssh')
 
     # Apache command
     print section_title('Create apache-reload command')
@@ -88,7 +94,7 @@ def setup(settings_path=None, **settings_patches):
     local('chmod 440 %s' % sudoer_file)
 
     # Make beanstalk access ssh
-    local('echo "AllowUsers User beanstalk" >> /etc/ssh/sshd_config')
+    local('sed -i.bak -e "/^AllowGroups wheel$/cAllowGroups wheel beanstalk" /etc/ssh/sshd_config')
     local('/etc/init.d/sshd restart')
 
     # Create homebase
@@ -96,3 +102,15 @@ def setup(settings_path=None, **settings_patches):
     local('mkdir -p %s' % beanstalk_stack_base)
     local('chmod o+rx %s' % beanstalk_stack_base)
     local('chown beanstalk:beanstalk %s' % beanstalk_stack_base)
+
+
+@task
+@beanstalk_role('server')
+def add_app(project_name):
+    print 'add_app: %s' % project_name
+
+
+@task
+@beanstalk_role('server')
+def update_app(project_name):
+    print 'update_app: %s' % project_name
